@@ -7,6 +7,7 @@ Copyright 2009      James Cameron <quozl@us.netrek.org>
 Copyright 2010      Ibragimov Rinat <ibragimovrinat@mail.ru>
 Copyright 2017      Stoney Sauce <stoneysauce@gmail.com>
 Copyright 2019      Daniel T. Borelli <danieltborelli@gmail.com>
+Copyright 2019      Jade Auer <jade@trashwitch.dev>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -74,6 +75,9 @@ main(int argc,
     }
   }
 
+  if (opt.note != NULL)
+    scrot_note_draw(image);
+
   if (!image)
     gib_eprintf("no image grabbed");
 
@@ -133,6 +137,8 @@ main(int argc,
       gib_eprintf("Unable to create scaled Image\n");
     else
     {
+      if (opt.note != NULL)
+        scrot_note_draw(image);
       filename_thumb = im_printf(opt.thumb_file, tm, NULL, NULL, thumbnail);
       scrot_check_if_overwrite_file(&filename_thumb);
       gib_imlib_save_image_with_error_return(thumbnail, filename_thumb, &err);
@@ -239,7 +245,7 @@ scrot_grab_mouse_pointer(const Imlib_Image image,
   DATA32 *pixels        = NULL;
 
 #ifdef __i386__
-  pixels = xcim->pixels;
+  pixels = (DATA32*)xcim->pixels;
 #else
   DATA32 data[width * height * 4];
 
@@ -356,6 +362,8 @@ scrot_sel_and_grab_image(void)
               GCFunction | GCForeground | GCBackground | GCSubwindowMode,
               &gcval);
 
+  XSetLineAttributes(disp, gc, opt.line_width, opt.line_style, CapRound, JoinRound);
+
   if ((XGrabPointer
        (disp, root, False,
         ButtonMotionMask | ButtonPressMask | ButtonReleaseMask, GrabModeAsync,
@@ -403,6 +411,9 @@ scrot_sel_and_grab_image(void)
             rect_w = ev.xmotion.x - rect_x;
             rect_h = ev.xmotion.y - rect_y;
 
+            if (rect_w == 0) ++rect_w;
+            if (rect_h == 0) ++rect_h;
+
             if (rect_w < 0) {
               rect_x += rect_w;
               rect_w = 0 - rect_w;
@@ -618,6 +629,10 @@ im_printf(char *str, struct tm *tm,
     if (*c == '$') {
       c++;
       switch (*c) {
+        case 'a':
+          gethostname(buf, sizeof(buf));
+          strcat(ret, buf);
+          break;
         case 'f':
           if (filename_im)
             strcat(ret, filename_im);
